@@ -26,15 +26,15 @@ class Mod3Solver : public Solver
 {
 public:
     explicit Mod3Solver(const Mod3 *dealer);
-    virtual int get_possible_moves(int *a, int *numout);
-    virtual bool isWon();
-    virtual void make_move(MOVE *m);
-    virtual void undo_move(MOVE *m);
-    virtual int getOuts();
-    virtual void translate_layout();
-    virtual MoveHint translateMove(const MOVE &m);
+    int get_possible_moves(int *a, int *numout) Q_DECL_OVERRIDE;
+    bool isWon() Q_DECL_OVERRIDE;
+    void make_move(MOVE *m) Q_DECL_OVERRIDE;
+    void undo_move(MOVE *m) Q_DECL_OVERRIDE;
+    int getOuts() Q_DECL_OVERRIDE;
+    void translate_layout() Q_DECL_OVERRIDE;
+    MoveHint translateMove(const MOVE &m) Q_DECL_OVERRIDE;
 
-    virtual void print_layout();
+    void print_layout() Q_DECL_OVERRIDE;
 
     const Mod3 *deal;
     int aces;
